@@ -1,7 +1,7 @@
 package Yars::Client;
 
 # ABSTRACT: Yet Another RESTful-Archive Service Client
-our $VERSION = '1.14'; # VERSION
+our $VERSION = '1.15'; # VERSION
 
 use strict;
 use warnings;
@@ -131,7 +131,7 @@ sub bucket_map_cached {
             #    server in the mojo template of the config.
             #    (see https://github.com/plicease/Yars#randomizing-the-server-choices)
             my %r = map { $_ => 1 } values %$cache;
-            if(grep { ! $r{$_} } ($self->_config->url, $self->_config->failover_urls))
+            if(grep { ! $r{$_} } ($self->_config->url, $self->_config->failover_urls( default => [] )))
             {
                 $self->{bucket_map_cached} = 0;
                 unlink $fn;
@@ -553,7 +553,7 @@ Yars::Client - Yet Another RESTful-Archive Service Client
 
 =head1 VERSION
 
-version 1.14
+version 1.15
 
 =head1 SYNOPSIS
 
